package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BasePosttypeInfo;

/**
 * 职位类型基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-20
 */
public interface BasePosttypeInfoMapper 
{
    /**
     * 查询职位类型基础信息
     * 
     * @param objid 职位类型基础信息ID
     * @return 职位类型基础信息
     */
    public BasePosttypeInfo selectBasePosttypeInfoById(Long objid);

    /**
     * 查询职位类型基础信息列表
     * 
     * @param basePosttypeInfo 职位类型基础信息
     * @return 职位类型基础信息集合
     */
    public List<BasePosttypeInfo> selectBasePosttypeInfoList(BasePosttypeInfo basePosttypeInfo);

    /**
     * 新增职位类型基础信息
     * 
     * @param basePosttypeInfo 职位类型基础信息
     * @return 结果
     */
    public int insertBasePosttypeInfo(BasePosttypeInfo basePosttypeInfo);

    /**
     * 修改职位类型基础信息
     * 
     * @param basePosttypeInfo 职位类型基础信息
     * @return 结果
     */
    public int updateBasePosttypeInfo(BasePosttypeInfo basePosttypeInfo);

    /**
     * 删除职位类型基础信息
     * 
     * @param objid 职位类型基础信息ID
     * @return 结果
     */
    public int deleteBasePosttypeInfoById(Long objid);

    /**
     * 批量删除职位类型基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBasePosttypeInfoByIds(String[] objids);

    /**
     * 查询职位类型基础信息列表
     *
     * @return 职位类型基础信息集合
     */
    public List<BasePosttypeInfo> selectAddBasePosttypeInfoList();

    /**
     * 查询职位类型基础信息列表修改下拉框
     *
     * @return 职位类型基础信息集合
     */
    public List<BasePosttypeInfo> selectEditBasePosttypeInfoList(String postTypeID);
}
